@@ -16,16 +16,13 @@ module Data.Text.ICU.Collate.Internal
       MCollator(..)
     , Collator(..)
     , UCollator
-    , equals
     , withCollator
     , wrap
     ) where
 
-import Data.Text.ICU.Internal (UBool, asBool)
 import Data.Typeable (Typeable)
 import Foreign.ForeignPtr (ForeignPtr, newForeignPtr, withForeignPtr)
 import Foreign.Ptr (FunPtr, Ptr)
-import System.IO.Unsafe (unsafePerformIO)
 
 -- $api
 --
@@ -41,9 +38,6 @@ data MCollator = MCollator {-# UNPACK #-} !(ForeignPtr UCollator)
 newtype Collator = C MCollator
     deriving (Typeable)
 
-instance Eq Collator where
-    (C a) == (C b) = unsafePerformIO $ equals a b
-
 withCollator :: MCollator -> (Ptr UCollator -> IO a) -> IO a
 withCollator (MCollator col) action = withForeignPtr col action
 {-# INLINE withCollator #-}
@@ -52,16 +46,5 @@ wrap :: Ptr UCollator -> IO MCollator
 wrap = fmap MCollator . newForeignPtr ucol_close
 {-# INLINE wrap #-}
 
--- | 'MCollator's are considered equal if they will sort strings
--- identically. This means that both the current attributes and the rules
--- must be equivalent.
-equals :: MCollator -> MCollator -> IO Bool
-equals a b = fmap asBool .
-  withCollator a $ \aptr ->
-    withCollator b $ ucol_equals aptr
-
 foreign import ccall unsafe "hs_text_icu.h &__hs_ucol_close" ucol_close
     :: FunPtr (Ptr UCollator -> IO ())
-
-foreign import ccall unsafe "hs_text_icu.h __hs_ucol_equals" ucol_equals
-    :: Ptr UCollator -> Ptr UCollator -> IO UBool
